==> central-repository-3.59.0.zip: ej/library/eclasspath/logging/1.2.0/CHANGELOG-1.2.0.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 1.2.0 - 2020-10-05

### Changed

 - Marked APIs with annotations for Null Analysis.
 - Updated implementation code to comply with Null Analysis.

## 1.1.1 - 2020-10-02

### Added

  - Added dependency to basictool.

### Changed

  - Update EDC dependency to 1.3.0.

### Fixed

  - Use `PackedMap` rather than `HashMap` in `LogManager`.

## 1.1.0 - 2019-03-05

### Changed

  - Use MMM.

### Fixed

  - J0162E-44: Fix descriptions of levels OFF and ALL.
  - Set initial level to anonymous loggers to ALL to comply with javadoc.

## 1.0.3 - 2016-04-01

### Added

  - Initial public revision.
  
---  
_Markdown_  
_Copyright 2017-2020 MicroEJ Corp. - EDC compliance and optimizations._  
_DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER._  
_ _  
_This code is free software; you can redistribute it and/or modify it_  
_under the terms of the GNU General Public License version 2 only, as_  
_published by the Free Software Foundation._  
_ _  
_This code is distributed in the hope that it will be useful, but WITHOUT_  
_ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or_  
_FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License_  
_version 2 for more details (a copy is included in the LICENSE file that_  
_accompanied this code)._  
_ _  
_You should have received a copy of the GNU General Public License version_  
_2 along with this work; if not, write to the Free Software Foundation,_  
_Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA._  
_ _  
_Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA_  
_or visit www.oracle.com if you need additional information or have any_  
_questions._  code will break IS2T warranties on the whole library._

==> central-repository-3.62.0.zip: ej/library/eclasspath/logging/1.2.1/CHANGELOG-1.2.1.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 1.2.1 - 2022-03-11

### Fixed

 - Change properties file to comply with MicroEJ naming convention. System properties files should have the suffix .properties.list

## 1.2.0 - 2020-10-05

### Changed

 - Marked APIs with annotations for Null Analysis.
 - Updated implementation code to comply with Null Analysis.

## 1.1.1 - 2020-10-02

### Added

  - Added dependency to basictool.

### Changed

  - Update EDC dependency to 1.3.0.

### Fixed

  - Use `PackedMap` rather than `HashMap` in `LogManager`.

## 1.1.0 - 2019-03-05

### Changed

  - Use MMM.

### Fixed

  - J0162E-44: Fix descriptions of levels OFF and ALL.
  - Set initial level to anonymous loggers to ALL to comply with javadoc.

## 1.0.3 - 2016-04-01

### Added

  - Initial public revision.
  
---  
_Markdown_  
_Copyright 2017-2022 MicroEJ Corp. - EDC compliance and optimizations._  
_DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER._  
_ _  
_This code is free software; you can redistribute it and/or modify it_  
_under the terms of the GNU General Public License version 2 only, as_  
_published by the Free Software Foundation._  
_ _  
_This code is distributed in the hope that it will be useful, but WITHOUT_  
_ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or_  
_FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License_  
_version 2 for more details (a copy is included in the LICENSE file that_  
_accompanied this code)._  
_ _  
_You should have received a copy of the GNU General Public License version_  
_2 along with this work; if not, write to the Free Software Foundation,_  
_Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA._  
_ _  
_Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA_  
_or visit www.oracle.com if you need additional information or have any_  
_questions._  code will break IS2T warranties on the whole library._
